==> darcs_2.4.4.orig.tar.gz: darcs-2.4.4/tests/issue942_push_apply_prehook.sh <==
#!/usr/bin/env bash
## Test for issue942 - remote apply prehook not invoked on darcs push
## We also test for posthooks along the way even though that's not part
## of the issue.
##
## Copyright (C) 2009 Eric Kow <kowey@darcs.net>
##
## Permission is hereby granted, free of charge, to any person
## obtaining a copy of this software and associated documentation
## files (the "Software"), to deal in the Software without
## restriction, including without limitation the rights to use, copy,
## modify, merge, publish, distribute, sublicense, and/or sell copies
## of the Software, and to permit persons to whom the Software is
## furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be
## included in all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
## EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
## MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
## NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
## BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
## ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
## CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
## SOFTWARE.

. ../tests/lib                  # Load some portability helpers.
rm -rf R S                      # Another script may have left a mess.
darcs init      --repo R        # Create our test repos.
echo 'apply prehook touch g' >R/_darcs/prefs/defaults
echo 'apply posthook touch h' >>R/_darcs/prefs/defaults
darcs get R S
cd S
touch f
darcs add f
darcs record -lam 'Add f'
test ! -e ../R/g
test ! -e ../R/h
darcs push -a
test -e ../R/g
test -e ../R/h

==> darcs_2.14.5.orig.tar.gz: darcs-2.14.5/tests/issue942_push_apply_prehook.sh <==
#!/usr/bin/env bash
## Test for issue942 - remote apply prehook not invoked on darcs push
## We also test for posthooks along the way even though that's not part
## of the issue.
##
## Copyright (C) 2009 Eric Kow <kowey@darcs.net>
##
## Permission is hereby granted, free of charge, to any person
## obtaining a copy of this software and associated documentation
## files (the "Software"), to deal in the Software without
## restriction, including without limitation the rights to use, copy,
## modify, merge, publish, distribute, sublicense, and/or sell copies
## of the Software, and to permit persons to whom the Software is
## furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be
## included in all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
## EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
## MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
## NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
## BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
## ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
## CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
## SOFTWARE.

. lib                  # Load some portability helpers.
rm -rf R S                      # Another script may have left a mess.
darcs init      --repo R        # Create our test repos.
echo 'apply prehook touch g' >R/_darcs/prefs/defaults
echo 'apply posthook touch h' >>R/_darcs/prefs/defaults
darcs get R S
cd S
touch f
darcs add f
darcs record -lam 'Add f'
test ! -e ../R/g
test ! -e ../R/h
darcs push -a
test -e ../R/g
test -e ../R/h
